@@ -39,7 +39,7 @@
 #  @see "CopyNumberChromosomalModel".
 # }
 #*/###########################################################################
-setConstructorS3("ChromosomeExplorer", function(model=NULL, zooms=2^(0:7), ..., version=c("3")) {
+setConstructorS3("ChromosomeExplorer", function(model=NULL, zooms=2^(0:6), ..., version=c("3")) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -487,124 +487,6 @@ setMethodS3("setup", "ChromosomeExplorer", function(this, ..., force=FALSE) {
 
 
 
-
-setMethodS3("writeAxesLayers", "ChromosomeExplorer", function(this, ...) {
-  model <- getModel(this);
-
-  path <- getPath(this);
-  path <- filePath(getParent(path), "axes,chrLayer");
-
-
-  if (getParallelSafe(this)) {
-    tryCatch({
-      path <- Arguments$getWritablePath(path);
-      plotAxesLayers(model, path=path, imageFormat="png", transparent=TRUE, ...);
-    }, error = function(ex) {})
-  } else {
-    path <- Arguments$getWritablePath(path);
-    plotAxesLayers(model, path=path, imageFormat="png", transparent=TRUE, ...);
-  }
-
-  invisible(path);
-}, private=TRUE)
-
-
-setMethodS3("writeGridHorizontalLayers", "ChromosomeExplorer", function(this, ...) {
-  model <- getModel(this);
-
-  path <- getPath(this);
-  path <- filePath(getParent(path), "gridH,chrLayer");
-
-
-  if (getParallelSafe(this)) {
-    tryCatch({
-      path <- Arguments$getWritablePath(path);
-      plotGridHorizontalLayers(model, path=path, imageFormat="png", transparent=TRUE, ...);
-    }, error = function(ex) {})
-  } else {
-    path <- Arguments$getWritablePath(path);
-    plotGridHorizontalLayers(model, path=path, imageFormat="png", transparent=TRUE, ...);
-  }
-
-  invisible(path);
-}, private=TRUE)
-
-
-
-setMethodS3("writeCytobandLayers", "ChromosomeExplorer", function(this, ...) {
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Validate arguments
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Get the model
-  model <- getModel(this);
-
-  path <- getPath(this);
-  path <- filePath(getParent(path), "cytoband,chrLayer");
-
-
-  if (getParallelSafe(this)) {
-    tryCatch({
-      path <- Arguments$getWritablePath(path);
-      plotCytobandLayers(model, path=path, imageFormat="png", transparent=TRUE, ...);
-    }, error = function(ex) {})
-  } else {
-    path <- Arguments$getWritablePath(path);
-    plotCytobandLayers(model, path=path, imageFormat="png", transparent=TRUE, ...);
-  }
-
-  invisible(path);
-}, private=TRUE)
-
-
-setMethodS3("getSampleLayerName", "Explorer", function(this, name, class="sampleLayer", ...) {
-  layer <- c(getSampleLayerPrefix(this), name, class);
-  layer <- paste(layer, collapse=",");
-  layer;
-}, private=TRUE)
-
-
-setMethodS3("writeRawCopyNumberLayers", "ChromosomeExplorer", function(this, ...) {
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Validate arguments
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Get the model
-  model <- getModel(this);
-
-  path <- getPath(this);
-  layer <- getSampleLayerName(this, "rawCNs");
-  path <- filePath(getParent(path), layer);
-
-  path <- Arguments$getWritablePath(path);
-  plotRawCopyNumbers(model, path=path, imageFormat="png", transparent=TRUE, ...);
-
-  invisible(path);
-}, private=TRUE)
-
-
-setMethodS3("writeCopyNumberRegionLayers", "ChromosomeExplorer", function(this, ...) {
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Validate arguments
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Get the model
-  model <- getModel(this);
-
-  # Not supported?
-  if (!inherits(model, "CopyNumberSegmentationModel"))
-    return(NULL);
-    
-  path <- getPath(this);
-  tags <- getAsteriskTags(model, collapse=",");
-  path <- filePath(getParent(path), sprintf("%s,sampleLayer", tags));
-
-  path <- Arguments$getWritablePath(path);
-  plotCopyNumberRegionLayers(model, path=path, imageFormat="png", transparent=TRUE, ...);
-
-  invisible(path);
-}, private=TRUE)
-
-
-
-
 setMethodS3("writeGraphs", "ChromosomeExplorer", function(x, arrays=NULL, ...) {
   # To please R CMD check.
   this <- x;
